from .collection_call import (
  CollectionCallSpanCapture
)


__all__ = [
  'CollectionCallSpanCapture'
]
